==> pheno-utils-0.3.7.4.tar.gz: pheno-utils-0.3.7.4/setup.py <==
from pkg_resources import parse_version
from configparser import ConfigParser
import json, os, sys
import shutil
import setuptools, shlex
assert parse_version(setuptools.__version__)>=parse_version('36.2')


def copy_tre_config():
    script_path = os.path.dirname(os.path.abspath(__file__))
    sys.stderr.write('This is an error message\n')
    sys.stderr.write(script_path)
    print(script_path)
    absolute_config_path = os.path.join(script_path, 'config_setup/config_tre.json')
    print(absolute_config_path)
    sys.stderr.write(absolute_config_path)
    with open(absolute_config_path, 'r') as openfile:
        json_object = json.load(openfile)
        print('wow')
        sys.stderr.write('wow')
    datasets_full_path = json_object['DATASETS_PATH']
    print(datasets_full_path)
    sys.stderr.write(datasets_full_path)
    if os.path.exists(datasets_full_path):
        # TRE MODE
        print('TRE MODE')
        sys.stderr.write('TRE MODE')
        if not os.path.exists(os.path.expanduser('~/.pheno')):
            print('yes', os.path.expanduser('~/.pheno'))
            sys.stderr.write(os.path.expanduser('~/.pheno'))
            os.makedirs(os.path.expanduser('~/.pheno'))
        print(absolute_config_path)
        sys.stderr.write(absolute_config_path)
        
        shutil.copy2(absolute_config_path, os.path.expanduser('~/.pheno/config.json'))

        
copy_tre_config()     

# note: all settings are in settings.ini; edit there, not here
config = ConfigParser(delimiters=['='])
config.read('settings.ini')
cfg = config['DEFAULT']

cfg_keys = 'version description keywords author author_email'.split()
expected = cfg_keys + "lib_name user branch license status min_python audience language".split()
for o in expected: assert o in cfg, "missing expected setting: {}".format(o)
setup_cfg = {o:cfg[o] for o in cfg_keys}

licenses = {
    'apache2': ('Apache Software License 2.0','OSI Approved :: Apache Software License'),
    'mit': ('MIT License', 'OSI Approved :: MIT License'),
    'gpl2': ('GNU General Public License v2', 'OSI Approved :: GNU General Public License v2 (GPLv2)'),
    'gpl3': ('GNU General Public License v3', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
    'bsd3': ('BSD License', 'OSI Approved :: BSD License'),
}
statuses = [ '1 - Planning', '2 - Pre-Alpha', '3 - Alpha',
    '4 - Beta', '5 - Production/Stable', '6 - Mature', '7 - Inactive' ]
py_versions = '3.6 3.7 3.8 3.9 3.10'.split()

requirements = shlex.split(cfg.get('requirements', ''))
if cfg.get('pip_requirements'): requirements += shlex.split(cfg.get('pip_requirements', ''))
min_python = cfg['min_python']
lic = licenses.get(cfg['license'].lower(), (cfg['license'], None))
dev_requirements = (cfg.get('dev_requirements') or '').split()

setuptools.setup(
    name = cfg['lib_name'],
    license = lic[0],
    classifiers = [
        'Development Status :: ' + statuses[int(cfg['status'])],
        'Intended Audience :: ' + cfg['audience'].title(),
        'Natural Language :: ' + cfg['language'].title(),
    ] + ['Programming Language :: Python :: '+o for o in py_versions[py_versions.index(min_python):]] + (['License :: ' + lic[1] ] if lic[1] else []),
    url = cfg['git_url'],
    packages = setuptools.find_packages(),
    include_package_data = True,
    install_requires = requirements,
    extras_require={ 'dev': dev_requirements },
    dependency_links = cfg.get('dep_links','').split(),
    python_requires  = '>=' + cfg['min_python'],
    long_description = open('README.md').read(),
    long_description_content_type = 'text/markdown',
    zip_safe = False,
    entry_points = {
        'console_scripts': cfg.get('console_scripts','').split(),
        'nbdev': [f'{cfg.get("lib_path")}={cfg.get("lib_path")}._modidx:d']
    },
    **setup_cfg)

==> pheno-utils-0.3.7.5.tar.gz: pheno-utils-0.3.7.5/setup.py <==
from pkg_resources import parse_version
from configparser import ConfigParser
import json, os, sys
import logging

import shutil
import setuptools, shlex
assert parse_version(setuptools.__version__)>=parse_version('36.2')

logging.basicConfig(level=logging.INFO, stream=sys.stderr)


def copy_tre_config():
    script_path = os.path.dirname(os.path.abspath(__file__))
    logging.info(script_path)
    print(script_path)
    
    absolute_config_path = os.path.join(script_path, 'config_setup/config_tre.json')
    print(absolute_config_path)
    logging.info(absolute_config_path)
    
    with open(absolute_config_path, 'r') as openfile:
        json_object = json.load(openfile)
        print('wow')
        logging.info('wow')
        
    datasets_full_path = json_object['DATASETS_PATH']
    print(datasets_full_path)
    logging.info(datasets_full_path)
    
    if os.path.exists(datasets_full_path):
        # TRE MODE
        print('TRE MODE')
        logging.info('TRE MODE')
        
        if not os.path.exists(os.path.expanduser('~/.pheno')):
            print('yes', os.path.expanduser('~/.pheno'))
            logging.info(os.path.expanduser('~/.pheno'))
            os.makedirs(os.path.expanduser('~/.pheno'))
            
        print(absolute_config_path)
        logging.info(absolute_config_path)
        
        shutil.copy2(absolute_config_path, os.path.expanduser('~/.pheno/config.json'))

        
copy_tre_config()     

# note: all settings are in settings.ini; edit there, not here
config = ConfigParser(delimiters=['='])
config.read('settings.ini')
cfg = config['DEFAULT']

cfg_keys = 'version description keywords author author_email'.split()
expected = cfg_keys + "lib_name user branch license status min_python audience language".split()
for o in expected: assert o in cfg, "missing expected setting: {}".format(o)
setup_cfg = {o:cfg[o] for o in cfg_keys}

licenses = {
    'apache2': ('Apache Software License 2.0','OSI Approved :: Apache Software License'),
    'mit': ('MIT License', 'OSI Approved :: MIT License'),
    'gpl2': ('GNU General Public License v2', 'OSI Approved :: GNU General Public License v2 (GPLv2)'),
    'gpl3': ('GNU General Public License v3', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
    'bsd3': ('BSD License', 'OSI Approved :: BSD License'),
}
statuses = [ '1 - Planning', '2 - Pre-Alpha', '3 - Alpha',
    '4 - Beta', '5 - Production/Stable', '6 - Mature', '7 - Inactive' ]
py_versions = '3.6 3.7 3.8 3.9 3.10'.split()

requirements = shlex.split(cfg.get('requirements', ''))
if cfg.get('pip_requirements'): requirements += shlex.split(cfg.get('pip_requirements', ''))
min_python = cfg['min_python']
lic = licenses.get(cfg['license'].lower(), (cfg['license'], None))
dev_requirements = (cfg.get('dev_requirements') or '').split()

setuptools.setup(
    name = cfg['lib_name'],
    license = lic[0],
    classifiers = [
        'Development Status :: ' + statuses[int(cfg['status'])],
        'Intended Audience :: ' + cfg['audience'].title(),
        'Natural Language :: ' + cfg['language'].title(),
    ] + ['Programming Language :: Python :: '+o for o in py_versions[py_versions.index(min_python):]] + (['License :: ' + lic[1] ] if lic[1] else []),
    url = cfg['git_url'],
    packages = setuptools.find_packages(),
    include_package_data = True,
    install_requires = requirements,
    extras_require={ 'dev': dev_requirements },
    dependency_links = cfg.get('dep_links','').split(),
    python_requires  = '>=' + cfg['min_python'],
    long_description = open('README.md').read(),
    long_description_content_type = 'text/markdown',
    zip_safe = False,
    entry_points = {
        'console_scripts': cfg.get('console_scripts','').split(),
        'nbdev': [f'{cfg.get("lib_path")}={cfg.get("lib_path")}._modidx:d']
    },
    **setup_cfg)
